@@ -65,7 +65,7 @@ sub ready{
     $self->interval($self->update_interval || 600,sub{
         return if $self->is_stop;
         return if not $self->is_update_group;
-        $self->update_group(is_blocking=>0,is_update_group_ext=>0,is_update_group_member=>1,is_update_group_member_ext=>0);
+        $self->update_group(is_blocking=>0,is_update_group_ext=>0,is_update_group_member=>$self->is_update_group_member,is_update_group_member_ext=>$self->is_update_group_member_ext);
     });
 
     $self->timer(60,sub{
