@@ -21,38 +21,48 @@ sub model_ext_authorize{
         $self->model_ext(0);
         return;
     } 
-    if($self->uid and $self->pwd){
-        $self->info("开始扩展信息授权...");
+    
+    if($self->login_type eq 'login' and $self->account !~ /^\d+$/){
+        $self->error("使用账号密码登录方式，account参数不是有效的QQ号码");
+        $self->stop();
+    }
+    if($self->pwd){
+        $self->info("开始账号密码方式登录...") if $self->login_type eq 'login';
+        $self->info("尝取扩展信息授权...") if $self->login_type eq 'qrlogin';
         my $ret = $self->_model_ext_prepare() && $self->_model_ext_check() && $self->_model_ext_login() && $self->_model_ext_check_sig();
         if($ret){
-            $self->info("扩展信息授权成功");
+            $self->model_ext($ret);
+            #$self->info("账号密码方式登录成功");
+            return 1;
         }
         else{
-            $self->info("扩展信息授权失败，无法获取扩展信息");
+            #$self->info("账号密码方式失败");
+            return 0;
         }
-        $self->model_ext($ret);
     }
     else{
-        $self->warn("未设置账号授权密码，无法获取扩展信息，已忽略");
+        $self->warn("未设置有效的登录密码，无法进行登录");
+        return 0;
     }
+    return 1;
 }
 sub _model_ext_prepare {
     my $self = shift;
-    $self->debug("扩展信息授权中(prepare)...");
+    $self->debug("账号登录中(prepare)...");
     my(undef,$ua,$tx) = $self->http_get('https://xui.ptlogin2.qq.com/cgi-bin/xlogin?appid=715030901&daid=73&pt_no_auth=1&s_url=http%3A%2F%2Fqun.qq.com%2F',{Referer=>'http://qun.qq.com/',ua_debug_res_body=>0, blocking=> 1});
     return $tx->res->code == 200?1:0;
 }
 
 sub _model_ext_check {
     my $self = shift;
-    $self->debug("扩展信息授权中(check)...");
+    $self->debug("账号登录中(check)...");
     my $content = $self->http_get(
         $self->gen_url('https://ssl.ptlogin2.qq.com/check',
             (
                 regmaster => '',
                 pt_tea    => 2,
                 pt_vcode  => 1,
-                uin       => $self->uid,
+                uin       => ($self->login_type eq 'login'?$self->account:$self->uid),
                 appid     => 715030901,
                 js_ver    => 10233,
                 js_type   => 1,
@@ -75,18 +85,18 @@ sub _model_ext_check {
         $_is_rand_salt = $is_rand_salt;
     }
     else{
-        $self->error("群扩展信息授权失败: 可能因为登录环境变化引起，解决方法参见：https://github.com/sjdy521/Mojo-Webqq/issues/183"); 
+        $self->error("账号登录失败: 可能因为登录环境变化引起，解决方法参见：https://github.com/sjdy521/Mojo-Webqq/issues/183");
     }
     return $retcode == 0? 1 : 0;
 }
 
 sub _model_ext_login{
     my $self = shift;
-    $self->debug("扩展信息授权中(login)...");
+    $self->debug("账号登录中(login)...");
     my $content = $self->http_get(
         $self->gen_url('https://ssl.ptlogin2.qq.com/login',
             (
-                u  => $self->uid,
+                u  => ($self->login_type eq 'login'?$self->account:$self->uid),
                 verifycode => $_verifycode,
                 pt_vcode_v1 => 0,
                 pt_verifysession_v1 => ,$_verifysession // $self->search_cookie('verifysession'),
@@ -118,7 +128,7 @@ sub _model_ext_login{
 
     my($retcode,undef,$api_check_sig,undef,$info,$nick) = $content =~/'([^']*)'/g;
     if($retcode != 0){
-        $self->warn("扩展信息授权失败: $info");
+        $self->warn("账号登录失败: $info");
     }
     else{
         $_api_check_sig = $api_check_sig;
@@ -128,8 +138,8 @@ sub _model_ext_login{
 
 sub _model_ext_check_sig {
     my $self = shift;
-    $self->debug("扩展信息授权中(check_sig)...");
-    my(undef,$ua,$tx) = $self->http_get($_api_check_sig);
+    $self->debug("账号登录中(check_sig)...");
+    my(undef,$ua,$tx) = $self->http_get($_api_check_sig,{ua_debug_res_body=>0});
     return $tx->res->code == 200?1:0;
 }
 
