@@ -6,6 +6,8 @@ sub Mojo::Webqq::Model::_get_user_info{
     my $headers = {
         Referer     =>  'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
         json        =>  1,
+        ua_request_timeout => $self->model_update_timeout,
+        ua_retry_times => 3,
     };
     my @query_string = (
         t               =>  time,
