@@ -62,6 +62,9 @@ sub call{
             };
             if($@){
                 $self->error("插件[ $_ ]执行错误: $@");            
+                if($@ =~ /Can't create listen socket: Address already in use/){
+                    $self->stop();
+                }
                 next;
             }
             $self->emit("plugin_call",$_);
